@@ -2,7 +2,7 @@ from ..loader import monkeypatch_schema
 from ..skeleton import Annotation, AnnotationPage, Canvas, ResourceItem
 
 
-class AddImageToCanvas:
+class CanvasHelpers:
 
     def add_image(self, image_url, anno_id=None, anno_page_id=None, **kwargs):
         """Adds an image to an existing canvas.
@@ -23,5 +23,21 @@ class AddImageToCanvas:
         self.items.append(anno_page)
         return anno_page
 
+    def add_thumbnail(self, image_url, **kwargs):
+        """Adds a thumbnail to an existing canvas.
 
-monkeypatch_schema(Canvas, AddImageToCanvas)
+        Args:
+            image_url (str): An HTTP URL which points to the thumbnail.
+            **kwargs (): see ResourceItem.
+
+        Returns:
+            new_thumbnail (ResourceItem): the newly-created thumbnail.
+        """
+        new_thumbnail = ResourceItem(id=image_url, type='Image', **kwargs)
+        if not self.thumbnail:
+            self.thumbnail = list()
+        self.thumbnail.append(new_thumbnail)
+        return new_thumbnail
+
+
+monkeypatch_schema(Canvas, CanvasHelpers)
