@@ -8,16 +8,12 @@ from ..skeleton import Canvas
 
 
 class SetHeightWidthDurationFileHelper:
-    """Introspect a file and set the height, width, and duration properties.
-
-    Args:
-        file_path_or_object (filepath or fileobject): the file path or file object to introspect
-
-    Returns:
-        None
-    """
-
     def set_hwd_from_file(self, file_path_or_object):
+        """Introspect a file and set the height, width, and duration properties.
+
+        Args:
+            file_path_or_object (Union[str, fp]): the file path or file object to introspect
+        """
         if isinstance(file_path_or_object, str) or isinstance(file_path_or_object, os.PathLike):
             filetype, _ = mimetypes.guess_type(file_path_or_object)
             if not filetype.startswith("image/"):
